@@ -1,14 +1,11 @@
 const ytdl = require('..');
 const HttpsProxyAgent = require('https-proxy-agent');
 
-const agent = HttpsProxyAgent({
-  ip: '111.111.111.111',
-  port: 8080,
-  // Remove this if you don't need to authenticate to your proxy.
-  auth: 'user:pass',
-});
+// Remove 'user:pass@' if you don't need to authenticate to your proxy.
+const proxy = 'http://user:pass@111.111.111.111:8080';
+const agent = HttpsProxyAgent(proxy);
 
-const stream = ytdl('https://www.youtube.com/watch?v=2UBFIhS1YBk', {
+const stream = ytdl('https://www.youtube.com/watch?v=aqz-KE-bpKQ', {
   requestOptions: { agent },
 });
 
