@@ -1,3 +1,5 @@
+const { setTimeout } = require('timers');
+
 // A cache that expires.
 module.exports = class Cache extends Map {
   constructor(timeout = 1000) {
@@ -5,8 +7,11 @@ module.exports = class Cache extends Map {
     this.timeout = timeout;
   }
   set(key, value) {
+    if (this.has(key)) {
+      clearTimeout(super.get(key).tid);
+    }
     super.set(key, {
-      tid: setTimeout(this.delete.bind(this, key), this.timeout),
+      tid: setTimeout(this.delete.bind(this, key), this.timeout).unref(),
       value,
     });
   }
@@ -17,12 +22,19 @@ module.exports = class Cache extends Map {
     }
     return null;
   }
-  async getOrSet(key, fn) {
+  getOrSet(key, fn) {
     if (this.has(key)) {
       return this.get(key);
     } else {
-      let value = await fn();
+      let value = fn();
       this.set(key, value);
+      (async() => {
+        try {
+          await value;
+        } catch (err) {
+          this.delete(key);
+        }
+      })();
       return value;
     }
   }
